"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createInsecureLocal = exports.createLocal = exports.createRemote = void 0;
const LocalBootstrap_1 = require("./http/LocalBootstrap");
const LocalInsecureBootstrap_1 = require("./http/LocalInsecureBootstrap");
const RemoteBootstrap_1 = require("./http/RemoteBootstrap");
/**
 * Creates a remote bootstrap to connect with a Hue bridge remotely
 * @param clientId The OAuth client id for your application.
 * @param clientSecret The OAuth client secret for your application.
 */
function createRemote(clientId, clientSecret) {
    return new RemoteBootstrap_1.RemoteBootstrap(clientId, clientSecret);
}
exports.createRemote = createRemote;
/**
 * Creates a local network bootstrap to connect with Hue bridge on a local network.
 * @param host The IP Address or FQDN of the he bridge you are connecting to.
 * @param port The port number to connect to, optional.
 */
function createLocal(host, port) {
    return new LocalBootstrap_1.LocalBootstrap(host, port);
}
exports.createLocal = createLocal;
/**
 * Creates a local network bootstrap over an insecure HTTP connection.
 * @param host The IP Address or FQDN of the he bridge you are connecting to.
 * @param port The port number to connect to, optional.
 */
function createInsecureLocal(host, port) {
    return new LocalInsecureBootstrap_1.LocalInsecureBootstrap(host, port);
}
exports.createInsecureLocal = createInsecureLocal;
